Data from a multiple baseline across behaviors design conducted by Thiemann & Goldstein (2001). The variables are as follows:
Study_ID. Study identifier.
case. Student identifier.
series. Series identifier.
outcome. Frequency of coded social communication skills, as measured by
a direct observation coding system with 15-second intervals recording for the occurrence
of any of the four social measures: contingent responses, securing attention, initiating
comments, and initiating requests.
time. Measurement occasion.
treatment. Indicator for treatment phase.
trt_time. Measurement occasion times treatment phase.
time_c. Measurement occasion centered at the follow-up time.
A data frame with 363 rows and 8 variables