Data from a multiple baseline across behaviors design conducted by Thiemann & Goldstein (2004). The variables are as follows:
Study_ID. Study identifier.
case. Student identifier.
series. Series identifier.
outcome. Frequency of unprompted targeted social communication skills,
as measured by a direct observation, paper and pencil coding system during the 10-minute
social activity for each behavior for all sessions.
time. Measurement occasion.
treatment. Indicator for treatment phase.
trt_time. Measurement occasion times treatment phase.
time_c. Measurement occasion centered at the follow-up time.
A data frame with 408 rows and 8 variables