Estimates a standardized mean difference effect size from a multi-level model estimated using brms::brm.

g_mlm_Bayes(mod, p_const, r_const, rconst_base_var_index = 1, cover = 95)

Arguments

mod

Fitted model of class brmsfit (estimated using brms::brm()), from which to estimate the effect size.

p_const

Vector of constants for calculating numerator of effect size. Must be the same length as fixed effects in mod.

r_const

Vector of constants for calculating denominator of effect size. Must be the same length as the number of variance component parameters in mod_denom.

rconst_base_var_index

Something, not really sure what.

cover

Confidence level.

Value

A list with the following components

g_ABPosterior mean effect size estimate
SE_g_ABApproximate standard error of mean effect size estimate
nuEstimated denominator degrees of freedom
CI_LLower bound of credible interval for effect size
CI_UUpper bound of credible interval for effect size
es_num_vecPosterior samples of effect size numerator
es_denom_vecPosterior samples of squared denominator of effect size
autocor_paramPosterior mean auto-correlation
var_paramPosterior mean of level-1 variance model parameter
rhoPosterior mean intra-class correlation

References

Pustejovsky, J. E., Hedges, L. V., & Shadish, W. R. (2014). Design-comparable effect sizes in multiple baseline designs: A general modeling framework. Journal of Educational and Behavioral Statistics, 39(4), 211-227. doi:10.3102/1076998614547577