g_mlm_Bayes.RdEstimates a standardized mean difference effect size from a
multi-level model estimated using brms::brm.
g_mlm_Bayes(mod, p_const, r_const, rconst_base_var_index = 1, cover = 95)Fitted model of class brmsfit (estimated using
brms::brm()), from which to estimate the effect size.
Vector of constants for calculating numerator of effect size.
Must be the same length as fixed effects in mod.
Vector of constants for calculating denominator of effect
size. Must be the same length as the number of variance component
parameters in mod_denom.
Something, not really sure what.
Confidence level.
A list with the following components
g_AB | Posterior mean effect size estimate |
SE_g_AB | Approximate standard error of mean effect size estimate |
nu | Estimated denominator degrees of freedom |
CI_L | Lower bound of credible interval for effect size |
CI_U | Upper bound of credible interval for effect size |
es_num_vec | Posterior samples of effect size numerator |
es_denom_vec | Posterior samples of squared denominator of effect size |
autocor_param | Posterior mean auto-correlation |
var_param | Posterior mean of level-1 variance model parameter |
rho | Posterior mean intra-class correlation |
Pustejovsky, J. E., Hedges, L. V., & Shadish, W. R. (2014). Design-comparable effect sizes in multiple baseline designs: A general modeling framework. Journal of Educational and Behavioral Statistics, 39(4), 211-227. doi:10.3102/1076998614547577